.. _installation:

Installation
============

Minimum requirements
--------------------

* `cftime <https://unidata.github.io/cftime>`_ >= 1.5
* `matplotlib <https://matplotlib.org/stable>`_
* `numpy <https://numpy.org/doc/stable>`_
* `python <https://docs.python.org/3>`_ >= 3.7

Installation methods
--------------------

nc-time-axis can be installed through `conda <https://docs.conda.io/projects/conda/en/latest/index.html>`_::

    conda install -c conda-forge nc-time-axis

or through `pip <https://pip.pypa.io/en/stable>`_::

    pip install nc-time-axis
